Enum punktf_lib::profile::MergeMode
source · pub enum MergeMode {
Overwrite,
Keep,
Ask,
}Expand description
This enum represents all available merge modes punktf supports. The merge
mode is important when a file already exists at the target location of a
Dotfile.
Variants
Overwrite
Overwrites the existing file.
Keep
Keeps the existing file.
Ask
Asks the user for input to decide what to do.