pub struct PunktfSource {
    pub root: PathBuf,
    pub profiles: PathBuf,
    pub dotfiles: PathBuf,
}
This struct represents the source directory used by punktf. The source directory is the central repository used to store Profiles and Dotfiles. punktf will only read data from these directories but never write to them.

The current structure looks something like this:

root/
+ profiles/
  ...
+ dotfiles/
  ...

Fields

root: PathBuf

The absolute root source path.

profiles: PathBuf

The absolute path to the profiles directory.

dotfiles: PathBuf

The absolute path to the dotfiles directory.

Implementations

Creates a instance from a root directory. During instantiation it checks if the root exists and is a directory. These checks will also be run for the root/profiles and root/dotfiles subdirectories. All the above mentioned paths will also be resolved by calling std::path::Path::canonicalize.

Errors

If any of the checks fail an error will be returned.

Returns the absolute path for the root directory.

Returns the absolute path to the root/profiles directory.

Returns the absolute path to the root/dotfiles directory.