LayeredProfile

Struct LayeredProfile 

pub struct LayeredProfile {
    pub profile_names: Vec<String>,
    pub target: Option<(usize, PathBuf)>,
    pub variables: LayeredVariables,
    pub transformers: Vec<(usize, ContentTransformer)>,
    pub pre_hooks: Vec<(usize, Hook)>,
    pub post_hooks: Vec<(usize, Hook)>,
    pub dotfiles: Vec<(usize, Dotfile)>,
    pub symlinks: Vec<(usize, Symlink)>,
}
Defines a profile that appears on different layers.

Fields

profile_names: Vec<String>

All names of the profile which where collected from the extend chain.

target: Option<(usize, PathBuf)>

The target of the deployment.

This is the first value found by traversing the extend chain from the top.

variables: LayeredVariables

The variables collected from all profiles of the extend chain.

transformers: Vec<(usize, ContentTransformer)>

The content transformer collected from all profiles of the extend chain.

pre_hooks: Vec<(usize, Hook)>

The pre-hooks collected from all profiles of the extend chain.

post_hooks: Vec<(usize, Hook)>

The post-hooks collected from all profiles of the extend chain.

dotfiles: Vec<(usize, Dotfile)>

The dotfiles collected from all profiles of the extend chain.

The index indexes into LayeredProfile::profile_names to retrieve the name of the profile from which the dotfile came from.

symlinks: Vec<(usize, Symlink)>

The symlinks collected from all profiles of the extend chain.

The index indexes into LayeredProfile::profile_names to retrieve the name of the profile from which the link came from.

Implementations

Source

impl LayeredProfile

pub fn build() -> LayeredProfileBuilder

Creates a new builder for a layered profile.

pub fn target(&self) -> Option<(&str, &Path)>

Returns the target path for the profile together with the index into LayeredProfile::profile_names.

pub fn target_path(&self) -> Option<&Path>

Returns the target path for the profile.

pub const fn variables(&self) -> &LayeredVariables

Returns all collected variables for the profile.

pub fn transformers_len(&self) -> usize

Returns all the count of collected transformers for the profile.

pub fn transformers(&self) -> impl Iterator<Item = &ContentTransformer>

Returns all collected content transformer for the profile.

pub fn pre_hooks(&self) -> impl Iterator<Item = &Hook>

Returns all collected pre-hooks for the profile.

pub fn post_hooks(&self) -> impl Iterator<Item = &Hook>

Returns all collected post-hooks for the profile.

pub fn dotfiles(&self) -> impl Iterator<Item = &Dotfile>

Returns all collected dotfiles for the profile.

Returns all collected symlinks for the profile.