Struct punktf_lib::profile::Profile

source ·
pub struct Profile {
    pub aliases: Vec<String>,
    pub extends: Vec<String>,
    pub variables: Option<Variables>,
    pub transformers: Vec<ContentTransformer>,
    pub target: Option<PathBuf>,
    pub pre_hooks: Vec<Hook>,
    pub post_hooks: Vec<Hook>,
    pub dotfiles: Vec<Dotfile>,
    pub symlinks: Vec<Symlink>,
}
A profile is a collection of dotfiles and variables, options and hooks.

Fields

aliases: Vec<String>

Aliases for this profile which can be used instead of the file name.

extends: Vec<String>

Defines the base profile. All settings from the base are merged with the current profile. The settings from the current profile take precendence. Dotfiles are merged on the dotfile level (not specific dotfile settings level).

variables: Option<Variables>

Variables of the profile. Each dotfile will have this environment.

transformers: Vec<ContentTransformer>

Content transform of the profile. Each dotfile will have these applied.

target: Option<PathBuf>

Target root path of the deployment. Will be used as file stem for the dotfiles when not overwritten by Dotfile::overwrite_target.

pre_hooks: Vec<Hook>

Hook will be executed once before the deployment begins. If the hook fails the deployment will not be continued.

post_hooks: Vec<Hook>

Hook will be executed once after the deployment begins.

dotfiles: Vec<Dotfile>

Dotfiles which will be deployed.

symlinks: Vec<Symlink>

Symlinks which will be deployed.

Implementations

Tries to load a profile from the file located at path.

This function will try to guess the correct deserializer by the file extension of path

Errors

An error is returned if the file does not exist or could not be read. An error is returned if the file extension is unknown or missing.