Transforms run once for each defined dotfile during the deploy process.

They can either be specified for a whole profile, in which case each dotfile is transformed by them or they can be attached to a specific dotfile.

The transformation takes place after the template resolving and takes the contents in a textual representation. After processing the text a new text must be returned.

Enums

List of all available Transforms.
Transformer which replaces line termination characters with either unix style (\n) or windows style (\r\b).

Traits

A transform takes the contents of a dotfile, processes it and returns a new version of the content.