Enum punktf_lib::profile::transform::ContentTransformer
source · pub enum ContentTransformer {
LineTerminator(LineTerminator),
}Expand description
List of all available Transforms.
These can be added to a Profile or a
Dotfile to modify the text content.
Variants
LineTerminator(LineTerminator)
Transformer which replaces line termination characters with either unix
style (\n) or windows style (\r\b).