Transform

Trait Transform 

pub trait Transform {
    // Required method
    fn transform(&self, content: String) -> Result<String>;
}
A transform takes the contents of a dotfile, processes it and returns a new version of the content.

The dotfile is either the text of a resolved template or a non-template dotfile.

Required Methods

fn transform(&self, content: String) -> Result<String>

Takes a string as input, processes it and returns a new version of it.

Errors

If any error occurs during the processing it can be returned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors