Module punktf_lib::template::source

source ·
This modules holds structures related to source files, ways to analyze them and to convert between byte positions and character positions.

Structs

Describes a location within a source file. The line is 1 indexed while the column is 0 indexed.
Identifies the position and the width of a multi-byte character in a Source.
Holds the contents of a file together with the origins where the content came from. Besides the origin it also holds some information used in error reporting.

Enums

This struct holds the origin from which a Source came from.
Identifies the position of a special width character in a Source. Special width in this context means a character with byte width != 1.