Enum punktf_lib::visit::deploy::deployment::DeployedDotfileKind
source · Expand description
Defines the type of dotfile.
Variants
Dotfile(Dotfile)
A normal dotfile.
Child(PathBuf)
A dotfile that is contained in a directory that is deployed.
PathBuf is the deploy path of the parent dotfile.
The parent should always be of type Dotfile(_).
Implementations