Module punktf_lib::visit::diff

source ·
A Visitor implementation which creates events for files which differ from the content it would have once deployed.

Structs

A Visitor implementation which checks for changes which would be made by a deployment. For each change an Event is emitted which can be processed by [Diff.0].

Enums

An event which is emitted for every differing item.