Struct punktf_lib::visit::diff::Diff

source ·
pub struct Diff<F>(_);
A Visitor implementation which checks for changes which would be made by a deployment. For each change an Event is emitted which can be processed by [Diff.0].

Implementations

Creates a new instance of the visitor.

Runs the visitor to completion for a given profile.