pub struct ResolvingVisitor<V>(/* private fields */);Expand description
An extension for a base Visitor to split up files into normal files and
template files.
All accepted files are checked up on receiving and the either directly send
out with Visitor::accept_file if they are a normal file or with
TemplateVisitor::accept_template if it is a template.
Implementations
Sourceimpl<V> ResolvingVisitor<V>where
V: TemplateVisitor,
impl<V> ResolvingVisitor<V>where
V: TemplateVisitor,
Sourcepub fn into_inner(self) -> V
pub fn into_inner(self) -> V
Gets the base Visitor.