Struct punktf_lib::profile::source::PunktfSource
source · Expand description
This struct represents the source directory used by punktf. The source
directory is the central repository used to store
Profiles and Dotfiles.
punktf will only read data from these directories but never write to them.
The current structure looks something like this:
root/
+ profiles/
...
+ dotfiles/
...Fields
root: PathBufThe absolute root source path.
profiles: PathBufThe absolute path to the profiles directory.
dotfiles: PathBufThe absolute path to the dotfiles directory.
Implementations
sourceimpl PunktfSource
impl PunktfSource
sourcepub fn from_root(root: PathBuf) -> Result<Self>
pub fn from_root(root: PathBuf) -> Result<Self>
Creates a instance from a root directory. During instantiation it
checks if the root exists and is a directory. These checks will also
be run for the root/profiles and root/dotfiles subdirectories. All
the above mentioned paths will also be resolved by calling
std::path::Path::canonicalize.
Errors
If any of the checks fail an error will be returned.