pub trait Transform {
// Required method
fn transform(&self, content: String) -> Result<String>;
}Expand description
A transform takes the contents of a dotfile, processes it and returns a new version of the content.
The dotfile is either the text of a resolved template or a non-template dotfile.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".