pub trait Transform {
    fn transform(&self, content: String) -> Result<String>;
}
A transform takes the contents of a dotfile, processes it and returns a new version of the content.

The dotfile is either the text of a resolved template or a non-template dotfile.

Required Methods

Takes a string as input, processes it and returns a new version of it.

Errors

If any error occurs during the processing it can be returned.

Implementors