Trait punktf_lib::profile::transform::Transform
source · Expand description
A transform takes the contents of a dotfile, processes it and returns a new version of the content.
The dotfile is either the text of a resolved template or a non-template dotfile.