Module punktf_lib::template::source
source · Expand description
This modules holds structures related to source files, ways to analyze them and to convert between byte positions and character positions.
Structs
Describes a location within a source file. The line is 1 indexed while
the column is 0 indexed.
Holds the contents of a file together with the origins where the content
came from. Besides the origin it also holds some information used in error
reporting.
Enums
This struct holds the origin from which a
Source came from.