pub struct DeploymentBuilder { /* private fields */ }Expand description
A builder for a Deployment.
Implementations
Sourceimpl DeploymentBuilder
impl DeploymentBuilder
Sourcepub fn add_dotfile(
&mut self,
path: PathBuf,
dotfile: Dotfile,
status: ItemStatus,
) -> &mut Self
pub fn add_dotfile( &mut self, path: PathBuf, dotfile: Dotfile, status: ItemStatus, ) -> &mut Self
Adds a dotfile with the given status to the builder.
Sourcepub fn add_child(
&mut self,
path: PathBuf,
parent: PathBuf,
status: ItemStatus,
) -> &mut Self
pub fn add_child( &mut self, path: PathBuf, parent: PathBuf, status: ItemStatus, ) -> &mut Self
Adds the child of a dotfile directory with the given status to the
builder.
Sourcepub fn add_link(
&mut self,
source: PathBuf,
target: PathBuf,
status: ItemStatus,
) -> &mut Self
pub fn add_link( &mut self, source: PathBuf, target: PathBuf, status: ItemStatus, ) -> &mut Self
Adds a symlink with the given status to the builder.
Sourcepub fn contains<P: AsRef<Path>>(&self, path: P) -> bool
pub fn contains<P: AsRef<Path>>(&self, path: P) -> bool
Checks if the builder already contains a dotfile for the given path.
Sourcepub fn get_dotfile<P: AsRef<Path>>(&self, path: P) -> Option<&Dotfile>
pub fn get_dotfile<P: AsRef<Path>>(&self, path: P) -> Option<&Dotfile>
Gets any dotfile already deployed at path.
This function ignores the status of the dotfile.
Sourcepub fn get_deployed_dotfile<P: AsRef<Path>>(&self, path: P) -> Option<&Dotfile>
pub fn get_deployed_dotfile<P: AsRef<Path>>(&self, path: P) -> Option<&Dotfile>
Gets any dotfile already deployed at path.
This function only returns a dotfile with ItemStatus::Success.
Sourcepub fn get_priority<P: AsRef<Path>>(&self, path: P) -> Option<&Priority>
pub fn get_priority<P: AsRef<Path>>(&self, path: P) -> Option<&Priority>
Gets the priority of the dotfile already deployed at path.
This function only evaluates a dotfile with ItemStatus::Success.
Sourcepub fn is_deployed<P: AsRef<Path>>(&self, path: P) -> Option<bool>
pub fn is_deployed<P: AsRef<Path>>(&self, path: P) -> Option<bool>
Checks if a dotfile was already successfully deployed at path.
This function only evaluates a dotfile with ItemStatus::Success.
Sourcepub fn finish(self) -> Deployment
pub fn finish(self) -> Deployment
Consumes self and creates a Deployment from it.
This will try to guess the state of the deployment by looking for any failed deployed dotfile.
Sourcepub fn success(self) -> Deployment
pub fn success(self) -> Deployment
Consumes self and creates a Deployment from it.
This will mark the deployment as success.
Sourcepub fn failed<S: Into<Cow<'static, str>>>(self, reason: S) -> Deployment
pub fn failed<S: Into<Cow<'static, str>>>(self, reason: S) -> Deployment
Consumes self and creates a Deployment from it.
This will mark the deployment as failed with the reason given with
reason.