Struct punktf_lib::visit::deploy::Deployer
source · pub struct Deployer<F> { /* private fields */ }Expand description
Responsible for deploying a profile.
This includes checking for merge conflicts, resolving children of a directory dotfile, parsing and resolving of templates and the actual writing of the dotfile to the target destination.
Implementations
sourceimpl<F> Deployer<F>where
F: Fn(&Path, &Path) -> Result<bool>,
impl<F> Deployer<F>where
F: Fn(&Path, &Path) -> Result<bool>,
sourcepub fn new(options: DeployOptions, merge_ask_fn: F) -> Self
pub fn new(options: DeployOptions, merge_ask_fn: F) -> Self
Creates a new instance.
sourcepub fn into_deployment(self) -> Deployment
pub fn into_deployment(self) -> Deployment
Retrieves the finished deployment from this instance.
sourcepub fn deploy(
self,
source: &PunktfSource,
profile: &mut LayeredProfile
) -> Deployment
pub fn deploy(
self,
source: &PunktfSource,
profile: &mut LayeredProfile
) -> Deployment
Tries to deploy the given profile.
Errors
Only hard errors will be returned as error, everthing else will be recorded in the Deployment on a dotfile level.