Module punktf_lib::visit::diff
source · Expand description
A Visitor implementation which creates events for
files which differ from the content it would have once deployed.
Structs
Enums
An event which is emitted for every differing item.